==> cert_creation-1.2.14.1113.6-sources.jar: ocr/activity/YishuIDCardActivity.java <==
package ocr.activity;

import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.os.Bundle;
import android.os.Environment;

import com.squareup.otto.Subscribe;
import com.xdja.safeclient.certcreation.event.FinishActivity;


/**
 * 南京亿数NFC识别身份证后的展示界面
 * Created by Administrator on 2018/7/30 0030.
 */
public class YishuIDCardActivity extends IDCardActivity {

    public static String dirName = Environment.getExternalStorageDirectory().getAbsolutePath() + "/faceapp";

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
    }

    @Override
    public void initIDFace() {
        super.initIDFace();

        byte[] image = getIntent().getByteArrayExtra("selfie");
        faceBitmap = Bytes2Bimap(image);

    }

    @Override
    public void rescan() {
        //扫描界面未结束，finish返回扫描界面
        finish();

      /*  Intent intent = new Intent(context, XiZangYishuNFCActivity.class);
        Bundle bundle = new Bundle();
        bundle.putString(FACE_IMG, faceImg);
        intent.putExtras(bundle);
        startActivity(intent);*/


    }

    @Override
    public void next() {
        super.next();
    }

    public Bitmap Bytes2Bimap(byte[] b) {
        if (b.length != 0) {
            return BitmapFactory.decodeByteArray(b, 0, b.length);
        } else {
            return null;
        }
    }

    @Subscribe
    public void handleFinishActivity(FinishActivity activity) {
        finish();
    }


}

==> cert_creation-1.3.14.0125-sources.jar: ocr/activity/YishuIDCardActivity.java <==
package ocr.activity;

import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.os.Bundle;
import android.os.Environment;

import com.squareup.otto.Subscribe;
import com.xdja.safeclient.certcreation.cache.ImageCache;
import com.xdja.safeclient.certcreation.event.FinishActivity;


/**
 * 南京亿数NFC识别身份证后的展示界面
 * Created by Administrator on 2018/7/30 0030.
 */
public class YishuIDCardActivity extends IDCardActivity {

    private static String dirName = Environment.getExternalStorageDirectory().getAbsolutePath() + "/faceapp";

    public static String getDirName() {
        return dirName;
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
    }

    @Override
    public void initIDFace() {
        super.initIDFace();

//        byte[] image = getIntent().getByteArrayExtra("selfie");
//        faceBitmap = Bytes2Bimap(image);
        faceBitmap = ImageCache.getInstance().getNfcFaceImg();
    }

    @Override
    public void rescan() {
        //扫描界面未结束，finish返回扫描界面
        finish();

      /*  Intent intent = new Intent(context, XiZangYishuNFCActivity.class);
        Bundle bundle = new Bundle();
        bundle.putString(FACE_IMG, faceImg);
        intent.putExtras(bundle);
        startActivity(intent);*/


    }

    @Override
    public void next() {
        super.next();
    }

    public Bitmap Bytes2Bimap(byte[] b) {
        if (b.length != 0) {
            return BitmapFactory.decodeByteArray(b, 0, b.length);
        } else {
            return null;
        }
    }

    @Subscribe
    public void handleFinishActivity(FinishActivity activity) {
        finish();
    }


}
